import React, { useState, useEffect } from "react";

import { BreadCrumbsUi } from "../../shared/UI/BreadCrumbsUi";
import {ButtonUi, ButtonUiType} from "../../shared/UI/ButtonUi";
import { LoaderUi } from "../../shared/UI/LoaderUi/LoaderUi";
import { DefaultDropDown } from "../../entities/DefaultDropDown";
import { DefaultPagination } from "../../entities/DefaultPagination";
import { AddAuctionModal } from "../../widgets/AddAuctionModal";
import { EditAuctionModal } from "../../widgets/EditAuctionModal";
import Form from 'react-bootstrap/Form';
import { AuctionItem } from "../../types";
import { filterItems } from "../../constants/data";

import { api } from "../../query/query";

import loupe from "../../shared/images/loupe.png"
import filterImg from "../../shared/images/filter.png"
import close from "../../shared/images/close.png"
import edit from "../../shared/images/edit.png"

import styles from "./auctionPage.module.scss"

export const AuctionPage = () => {

    const [auctionItems, setAuctionItems] = useState<AuctionItem[]>([])

    const [openAddModal, setOpenAddModal] = useState(false)

    const [loader, setLoader] = useState(false)

    const [openEditModal, setOpenEditModal] = useState(false)

    const [currentEditAuction, setCurrentEditAuction] = useState({
        uuid: '018c448e-c7d7-7092-b151-08f8d8bc410e',
        dateCreate: "2023-12-07 16:54:17",
        name: '',
        auctionStartDate: "2023-12-22 16:03:00",
        description: "",
        requestsEndDate: "2023-12-21 16:03:00",
        requestsStartDate: "2023-12-18 16:06:00",
        status: 'Сбор заявок'
    })

    const addNewAuction = (newAction: string) => {
        setAuctionItems((prevValue) => [...prevValue, {
            uuid: '018c448e-c7d7-7092-b151-08f8d8bc480e',
            dateCreate: "2023-12-07 16:54:17",
            name: newAction,
            auctionStartDate: "2023-12-22 16:03:00",
            description: "",
            requestsEndDate: "2023-12-21 16:03:00",
            requestsStartDate: "2023-12-18 16:06:00",
            status: 'Сбор заявок'
        }])
    }

    const editAuctionItem = (newAuctionName: string, currentEditAuctionId: string) => {
        setAuctionItems((prevValue) => {
            return prevValue.map((item) => {
                if (item.uuid === currentEditAuctionId) {
                    return {...item, name: newAuctionName}
                }
                return item
            })
        })
    }

    const getCorrectDate = (day:string) => {
        const months = [
            "января",
            "февраля",
            "марта",
            "апреля",
            "мая",
            "июня",
            "июля",
            "августа",
            "сентября",
            "октября",
            "ноября",
            "декабря",
        ];
        return `${new Date(day).getDate()} ${
            months[new Date(day).getMonth()]
        } ${new Date(day).getFullYear()} года`;
    }

    useEffect(() => {
        setLoader(true)
        api.get('/auctions').then((res) => {
            setAuctionItems(res.data)
            setLoader(false)
        })
    }, [])

    return (
        <div className={styles.home}>
            <BreadCrumbsUi links={[
                { name: "Главная", link: "/" }
            ]} />
            <h2 className={styles.home__title}>Аукционы</h2>
            <div className={styles.home__info}>
                <div className={styles.info__top}>
                    <ButtonUi event={() => setOpenAddModal(true)} title={'+ Добавить аукцион'} variant={ButtonUiType.PRIMARY} />
                    <div className={styles.info__search}>
                        <Form.Control
                            type="text"
                            placeholder="Найти аукцион"
                        />
                        <img src={loupe} alt='loupe' />
                    </div>
                </div>
                <div className={styles.info__filters}>
                    <img className={styles.info__filtersImg} src={filterImg} alt="filter" />
                    <div className={styles.info__filters__items}>
                        {filterItems.map((item) => {
                            return <DefaultDropDown key={item.title} title={item.title} options={item.options} />
                        })}
                    </div>
                    <ButtonUi
                        title={'Сбросить фильтры'}
                        variant={ButtonUiType.PRIMARY}
                        img={<img src={close} alt="cross" />} />
                    <ButtonUi title={'Применить'} variant={ButtonUiType.INFO} />
                </div>
                <div className={styles.info__tableWrapper}>
                    {loader ?
                        <LoaderUi animation={'border'} variant={'primary'} />
                        :
                        <>
                            <table>
                                <thead>
                                <tr className={styles.tableItem}>
                                    <td>№</td>
                                    <td>Название аукциона</td>
                                    <td>Прием заявок</td>
                                    <td>Проведение</td>
                                    <td>Статус</td>
                                </tr>
                                </thead>
                                <tbody>
                                {auctionItems.map((item) => {
                                    return <tr className={styles.tableItem} key={item.uuid}>
                                        <td>{item.uuid}</td>
                                        <td className={styles.tableItem__name}>{item.name}</td>
                                        <td>{getCorrectDate((item.requestsStartDate))}</td>
                                        <td>{item.dateCreate}</td>
                                        <td>{item.status}</td>
                                        <td className={styles.tableItem__edit}>
                                            <img src={edit} alt="edit" onClick={() => {
                                                setCurrentEditAuction(item)
                                                setOpenEditModal(true)
                                            }}/>
                                        </td>
                                    </tr>
                                })}
                                </tbody>
                            </table>
                            <DefaultPagination pageCount={10} currentPage={2} />
                        </>
                    }
                </div>
            </div>
            <AddAuctionModal
                showModal={openAddModal}
                onHide={() => setOpenAddModal(false)}
                addNewItem={addNewAuction} />
            <EditAuctionModal
                showModal={openEditModal}
                onHide={() => setOpenEditModal(false)}
                currentAuction={currentEditAuction}
                editAuctionItem={editAuctionItem} />
        </div>
    );
};
